
:LastChangedDate: $LastChangedDate$
:LastChangedRevision: $LastChangedRevision$
:LastChangedBy: $LastChangedBy$

Twisted Web In 60 Seconds
=========================

.. toctree::
   :hidden:

   static-content
   dynamic-content
   static-dispatch
   dynamic-dispatch
   error-handling
   custom-codes
   handling-posts
   other-request-bodies
   rpy-scripts
   asynchronous
   asynchronous-deferred
   interrupted
   logging-errors
   access-logging
   wsgi
   http-auth
   session-basics
   session-store
   session-endings


This set of examples contains short, complete applications of :py:mod:`twisted.web`.
For subjects not covered here, see the :doc:`Twisted Web tutorial <../using-twistedweb>` and the API documentation.

#. :doc:`Serving static content from a directory <static-content>`
#. :doc:`Generating a page dynamically <dynamic-content>`
#. :doc:`Static URL dispatch <static-dispatch>`
#. :doc:`Dynamic URL dispatch <dynamic-dispatch>`
#. :doc:`Error handling <error-handling>`
#. :doc:`Custom response codes <custom-codes>`
#. :doc:`Handling POSTs <handling-posts>`
#. :doc:`Other request bodies <other-request-bodies>`
#. :doc:`rpy scripts (or, how to save yourself some typing) <rpy-scripts>`
#. :doc:`Asynchronous responses <asynchronous>`
#. :doc:`Asynchronous responses (via Deferred) <asynchronous-deferred>`
#. :doc:`Interrupted responses <interrupted>`
#. :doc:`Logging errors <logging-errors>`
#. :doc:`Access logging <access-logging>`
#. :doc:`WSGIs <wsgi>`
#. :doc:`HTTP authentication <http-auth>`
#. :doc:`Session basics <session-basics>`
#. :doc:`Storing objects in the session <session-store>`
#. :doc:`Session endings <session-endings>`
